@@ -36,7 +36,7 @@ def logger(output):
             f1.write('{}:{}\n'.format(i,output[i]))
         f1.write('\n********************************Log End********************************\n')
     
-    append_dict_as_row(cpath+str(output['Function Name'])+'.csv',deepcopy(output),output.keys())
+    append_dict_as_row(cpath+str(output['Function Name'])+'.csv',output,output.keys())
 
     
 
@@ -92,8 +92,9 @@ def profile(func,param=None):
     except psutil.AccessDenied:
         output["username"] = "N/A"
 
-    optprinter(output)
-    logger(output)
+    cpy = deepcopy(output)
+    optprinter(cpy)
+    logger(cpy)
 
     return output
 
